#' ---
#' title: 'Meta-analysis of the parasitism levels of Harmonia axyridis'
#' author: ['Gilles San Martin']
#' date: "`r Sys.setlocale('LC_ALL', 'en_GB.UTF-8'); format(Sys.time(), '%d %B %Y')`"
#' 
#' output:  
#'      #pdf_document:
#'      bookdown::pdf_document2:
#'          toc: true
#'          toc_depth: 5
#'          fig_caption: true
#'          number_sections: true
#'          latex_engine: pdflatex
#'          # latex_engine : xelatex
#'          highlight: default # default # espresso # zenburn
#' geometry: margin=0.7in
#' documentclass: article # report
#' fontsize: 11pt
#' fontfamily: lmodern # mathpple # times # utopia # lmodern # bookman # mathpazo # for pdflatex engine
#' header-includes:
#'      - \usepackage{float} # probably unnecessary with fig.pos = "H"
#'      - \usepackage{fancyvrb}
#'      - \usepackage{graphicx} # needed for fig.align = 'center' option
#'      - \usepackage{pdflscape} # to have some pages in landscape orientation
#' ---

# /* 
# ---------------- This part is just for report production -------------------
# */

#+ echo = FALSE, warning = FALSE, error = FALSE, message = FALSE
# source("/home/gilles/stats/makereport.R")
# makereport("template_spin.R", output = c("latex", "odt", "html"), odtdpi = 300, wd= "/home/gilles/stats")

library(knitr)
opts_chunk$set(echo=FALSE, results= "markup", cache = TRUE, 
               dev = c("cairo_pdf"), fig.width = 10/2.54, fig.height= 10/2.54, 
               fig.align='center', dpi = 500,  dev.args=list(bg='white'), 
               fig.cap = '  ',  fig.pos = "H", 
               warning = FALSE, error = FALSE, message = FALSE, 
               tidy = FALSE, tidy.opts=list(width.cutoff=95))
library(pander)
panderOptions("table.style" , "rmarkdown")
panderOptions("table.split.table" , Inf)
panderOptions("table.alignment.rownames" , "right")

# load ggplot, change the default theme and change the locale (language = English)
library(ggplot2)
#+ results = "hide", echo = FALSE
Sys.setlocale("LC_ALL", 'en_GB.UTF-8')
mytheme <- theme_bw(10) + theme(axis.text.x=element_text(size=8),
                                legend.key = element_rect(color = NA))
theme_set(mytheme)


options(width = 95)



#'
#'  
#' *********************************************************************************
#'
#' \newpage
#' 


# /* 
# ---------------- Load packages and scripts -------------------
# */

#' 
#' # Introduction - context
#' 
#' Data from the review paper : 
#' 
#' Ceryngier et al. (submitted in 2017) Predators and parasitoids of the harlequin ladybird, 
#' Harmonia axyridis, in its native range and invaded areas. Biological Invasions
#' 
#' This analysis was performed by Gilles San Martin with inputs from other authors of the 
#' review, mainly Piotr Ceryngier and Danny Haelewaters.
#' The full analysis, R code and raw data are available from the following public figshare 
#' repository : https://figshare.com/s/5d1a0d38be7d0941a455
#' 
#' 
#' We analysed only the parasitoïd data from tables 3 and 4 of the paper. For 
#' _Dinocampus coccinellae_, we used both parasitism rates determined by dissection of field
#' collected ladybirds
#' and emergence level of the parasitoïds (in separate analyses) and for _Phalacrotophora spp._
#' we used only the parasitism level ascertained as the proportion of field collected 
#' ladybirds pupae giving rise to the parasitoïd larvae. 
#' For these three dataset, we checked if we could find differences between regions, between 
#' species and if we could find temporal trends.
#' 
#' These data are mainly data gathered from the literature, with different protocols, scope, etc 
#' and all the problems that can occur with this kind of data.   
#' For the parasitism/emergence rate data we generally have only one rounded percentage value 
#' and the total number of observations. As the rounded % is not an exact ratio of two integers
#' this causes some warnings when used in binomial GLMs. However this should be a minor concern.
#' For the Phalacrotophora data we have artificialy fixed the total number of observations to 
#' a conservative value when it was not available in the literature 
#' (see chapter \@ref(Phalaco) for more details).
#' 

#'
#' \newpage
#' 

# /* 
# ---------------- Load packages and scripts -------------------
# */

#+ echo = FALSE
# source("/home/gilles/stats/mytoolbox.R")

setwd("/home/gilles/stats/OtherRprojects/PiotrCeryngier/Haraxy_parasitoids/")


library(car)
library(reshape)
library(lme4)



#' 
#' # _Dinocampus coccinellae_ parasitism rate
#' 
#' 
#' Summary of the data : 
#' 

d <- read.csv("data/Dinocampus.csv")
d[d$Host == "Coccinella septempunctata brucki", "Host"] <- "Coccinella septempunctata"
summary(d)


# /* 
# ---------------- Dinocampus : Comparing parasitism rates between regions -------------------
# */

#'
#' \newpage
#' 
#' 
#' ## Comparing parasitism rates between regions
#' 
#' ### Graph 
#' 

#+ fig.width = 9/2.54, fig.height = 7/2.54
# dev.new(width = 9/2.54, height = 7/2.54)
tmp <- droplevels(d[d$Host == "Harmonia axyridis" & !is.na(d$Parasitism_rate),])
ggplot(tmp, aes(y = Parasitism_rate, x = Continent)) + 
    geom_point(aes(size = Parasitism_N), shape = 1) +
    facet_wrap(~Host) +
    ylab("Dinocampus coccinellae\nParasitism rate (%)") + xlab("") +
    scale_size_continuous(name = "Sample size", breaks = c(14, 100, 250, 450, 1652))+
    theme_bw() +
    theme(legend.position = "right", axis.text.x=element_text(angle=45, hjust=1))


#'
#' ### GLM
#'
#' ***Is the parasitism rate of H. axyridis different between regions (continents) ?***
#' 
#' We performed a Binomial GLM with a quasilikelihood approach to estimate the 
#' overdispersion coefficient (that is quite high here : ~ 31).   
#' There is no statistically significant difference between the regions 
#' (quasibinomial GLM, $F_{3,10}$ = 3.66, p = 0.35)   
#' NB : we use a specific F test adapted to overdispersed GLMs instead of the more classical
#' Likelihood Ratio Test
#' 
m <- glm(Parasitism_rate/100 ~ Continent, weight = Parasitism_N, 
         data = tmp, family = quasibinomial)
pander(Anova(m, test = "F"))

#'
#' \newpage
#' 
summary(m)




# /* 
# ---------------- Dinocampus : Comparing parasitism rates between species -------------------
# */

#'
#' \newpage
#' 
#' 
#' ## Comparing parasitism rate between species
#' 
#' ### Graphs 
#' 
#' The data for the other species than H. axyridis are quite scarce : 
#' 

#+ fig.width = 20/2.54, fig.height = 9/2.54
# dev.new(width = 20/2.54, height = 9/2.54)
tmp <- droplevels(d[!is.na(d$Parasitism_rate),])
ggplot(tmp, aes(y = Parasitism_rate, x = Continent)) + 
    geom_point(aes(size = Parasitism_N), shape = 1) +
    facet_wrap(~Host,  nrow = 1) + 
    scale_size_continuous(name = "Sample size", breaks = c(14, 100, 250, 450, 1652))+
    ylab("Dinocampus coccinellae\nParasitism rate (%)") + xlab("") + 
    theme_bw() +
    theme(axis.text.x=element_text(angle=45, hjust=1), legend.position = "top")

#' 
#' We could compare the parasitism rate of H.axiridis and the parasitism rate 
#' of all other species confounded. We keep the native range data separated from the invades areas.
#' The lines connect observations from the same study and the same year (ie data that are directly comparable). 
#'    
#'    
#'    

tmp <- droplevels(d[!is.na(d$Parasitism_rate),])
tmp$Species <- as.character(tmp$Host)
tmp[tmp$Species != "Harmonia axyridis", "Species"] <- "Other sp."
tmp[tmp$Species == "Harmonia axyridis", "Species"] <- "H.axyridis"
tmp$Species <- factor(tmp$Species)
# crates an ID variable for each study in a given year
tmp$Study_ID <- factor(paste(tmp$Year, tmp$Reference))
tmp$Observation_ID <- factor(1:nrow(tmp))


# ggplot(tmp, aes(y = Parasitism_rate, x = Species)) + 
#     geom_point(aes(size = Parasitism_N), shape = 1) +
#     geom_line(aes(group = Study_ID), color = "gray50") +
#     facet_wrap(~Range) + 
#     scale_size_continuous(name = "Sample size", breaks = c(14, 100, 250, 450, 1652))+
#     ylab("Parasitism rate (%)") + xlab("") +
#     theme_bw()


tmp2 <- tmp[, c("Parasitism_rate", "Species", "Range", "Study_ID"),]
tmp2 <- merge(tmp2[tmp2$Species == "H.axyridis",], tmp2[tmp2$Species != "H.axyridis",], 
              by = "Study_ID", all = TRUE)
colnames(tmp2)[4] <- "Range"

#+ fig.width = 12/2.54, fig.height = 6/2.54
# dev.new(width = 12/2.54, height = 6/2.54)
ggplot(tmp, aes(y = Parasitism_rate, x = Species)) + 
    geom_point(aes(size = Parasitism_N), shape = 1) +
    geom_segment(aes(group = Study_ID, 
                     xend = Species.x, yend = Parasitism_rate.x, 
                     x = Species.y, y = Parasitism_rate.y), 
                 color = "gray50", data = tmp2) +
    facet_wrap(~Range) + 
    scale_size_continuous(name = "Sample size", breaks = c(14, 100, 250, 450, 1652))+
    ylab("Dinocampus coccinellae\nParasitism rate (%)") + xlab("") +
    theme_bw()

#'
#' \newpage
#'
#' 
#' ### Binomial GLMM
#' 
#' ***Is the parasitsim level different between H.axiridis and the other species ?***
#' 
#' We used only the data from the invaded regions because the data from the native range was too scarce.   
#' We used a binomial Generalized Linear Mixed Model (GLMM) with the parasitism rate as 
#' response and the Species (H. axyridis vs Other species) as fixed explanatory variable.
#' The study (data from one publication and one year) was used as random effect. 
#' An observation level ID was added as random effect to take into account any overdispersion. 
#' 
#' The results show that there the other species have a significantly higher parasitism rate
#' (binomial GLMM coefficient = 1.11, se = 0.455, z = 2.44, p = 0.0147)
#' 
#' Note : The overdispersion is limited in this model (~4) and excluding the observation level 
#' random effect makes the results even more significant.
#' 
m <- glmer(Parasitism_rate/100 ~ Species + (1 |Study_ID) + (1|Observation_ID), 
           weights = Parasitism_N, family = binomial, 
           data = tmp[tmp$Range == "Invaded area",])

# round(plogis(c(fixef(m)[1] fixef(m)[1] + fixef(m)[2])) *100,2)
# round((plogis(fixef(m)[1]) - plogis(fixef(m)[1] + fixef(m)[2])) *100,2)
# overdisp(m)
summary(m)

#'
#' \newpage
#'
#' 
#' ### Paired t test by permutation
#' 
#' We tried a simpler approach with a paired t test using only the data for which 
#' there was both measures of parasitism for H.axiridis and other species (and repeating 
#' the data for H.axyridis when there are several other species in the same study - this is not optimal).
#' As the parasitism rate could not be expected to follow a normal distribution we estimated the p value
#' with a permutation test (10000 permutations), however the p value from the permutation test is quite similar
#' to the p value of the standard paired t test.
#' 
 


tmp3 <- tmp2[!is.na(tmp2$Parasitism_rate.y) & tmp2$Range == "Invaded area", ]
tmp3 <- tmp3[c("Parasitism_rate.y", "Parasitism_rate.x")]

# Observed t statistic from a paired t test
res <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)
obs.t <- res$statistic

nperm = 10000 # number of permutations
perm.t <- vector(length = nperm)
set.seed(1234)
for (i in 1:(nperm-1)) {
    tmp3[] <- sample(as.matrix(tmp3)) # permute the data
    perm.t[i] <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)$statistic
}
perm.t[nperm] <- obs.t
perm.p <- 1 -(sum(abs(obs.t) >= abs(perm.t))/nperm)

res <- data.frame(t = round(res$statistic, 4), df = res$parameter, 
                  p.value = round(res$p.value, 4), "perm.p.value" = perm.p)

#' 
#' The paired difference of parasitism level between H. axyridis and the other species 
#' in the invaded areas is close to the significance 0.05 alpha level : t = 2.16, df = 5, p = `r perm.p`
#'  
#

pander(res)

#' 
#' If we add the single additionnal paired data from the native range, the paired differences
#' becomes significant : 
#' 

tmp3 <- tmp2[!is.na(tmp2$Parasitism_rate.y), ]
tmp3 <- tmp3[c("Parasitism_rate.y", "Parasitism_rate.x")]

# Observed t statistic from a paired t test
res <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)
obs.t <- res$statistic

nperm = 10000 # number of permutations
perm.t <- vector(length = nperm)
set.seed(1234)
for (i in 1:(nperm-1)) {
    tmp3[] <- sample(as.matrix(tmp3)) # permute the data
    perm.t[i] <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)$statistic
}
perm.t[nperm] <- obs.t
perm.p <- 1 -(sum(abs(obs.t) >= abs(perm.t))/nperm)

res <- data.frame(t = round(res$statistic, 4), df = res$parameter, 
                  p.value = round(res$p.value, 4), "perm.p.value" = perm.p)

pander(res)


#' 
#' ### Conclusion
#' 
#' The data seem to consistently points toward a significantly lower level of parasitism 
#' of H. axyridis by D. coccinellae.  
#' This is based on a variety of data collected from the literature from studies using different
#' protocols, with different objectives and with no systematic assessment of the native fauna. 
#' So these results should be confirmed by more standardised approaches.
#' 


# /* 
# ---------------- Dinocampus : Evolution of parasitism across time -------------------
# */

#'
#' \newpage
#' 
#' 
#' ## Changes in parasitism rate across time
#' 
#' The idea here was to test if there could be a time lag between the invasion and the adoption
#' of a new host by local parasitoïds (as observed in the parasitic fungus _Hesperomyces virescens_ 
#' sensu Haelewaters et al. 2017).
#' 
#' For the data collected during a range of years (e.g. 2004-2008), we use the mean on the range as "year".
#' 
#' The data don't seem to show any trend of the parasitism rate across time.
#' However the temporal data are quite limited and probably not directly comparable.
#' In Europe most of the data are close to the invasion start and we have less recent data.
#' 

#+ fig.width = 18/2.54, fig.height = 7/2.54
# dev.new(width = 18/2.54, height = 7/2.54)
tmp <- droplevels(d[d$Host == "Harmonia axyridis" & !is.na(d$Parasitism_rate),])
tmp$Year <- rowMeans(tmp[, c("Year_start", "Year")], na.rm = TRUE)
ggplot(tmp, aes(y = Parasitism_rate, x = Year)) + 
    geom_point(aes(size = Parasitism_N), shape = 1) +
    facet_wrap(~Continent, scales = "free", nrow = 1) +
    ylab("Dinocampus coccinellae\nParasitism rate (%)") + xlab("") +
    scale_size_continuous(name = "Sample size", breaks = c(14, 100, 250, 450, 1652))+
    theme_bw() +
    theme(legend.position = "top", axis.text.x=element_text(angle=45, hjust=1))





# /* 
# ---------------- Dinocampus : Comparing emergence rates between regions -------------------
# */

#'
#' \newpage
#' 
#' # _Dinocampus coccinellae_ emergence rate
#' 
#' ## Comparing emergence rates between regions
#' 
#' ### Graph 
#' 

#+ fig.width = 9/2.54, fig.height = 7/2.54
# dev.new(width = 9/2.54, height = 7/2.54)
tmp <- droplevels(d[d$Host == "Harmonia axyridis" & !is.na(d$Emergence_rate),])
ggplot(tmp, aes(y = Emergence_rate, x = Continent)) + 
    geom_point(aes(size = Emergence_N), shape = 1) +
    facet_wrap(~Host) +
    ylab("Dinocampus coccinellae\nEmergence rate (%)") + xlab("") +
    scale_size_continuous(name = "Sample size", breaks = c(35, 57, 125, 500, 18952))+
    theme_bw() +
    theme(legend.position = "right", axis.text.x=element_text(angle=45, hjust=1))


#'
#' ### GLM
#'
#' ***Is the parasitism rate of H. axyridis different between regions (continents) ?***
#' 
#' We performed a Binomial GLM with a quasilikelihood approach to estimate the 
#' overdispersion coefficient (that is quite high here : ~ 31).   
#' There is no statistically significant difference between the regions 
#' (quasibinomial GLM, $F_{3,12}$ = 0.0199, p = 0.99)   
#' NB : we use a specific F test adapted to overdispersed GLMs instead of the more classical
#' Likelihood Ratio Test
#' 
m <- glm(Emergence_rate/100 ~ Continent, weight = Emergence_N, 
         data = tmp, family = quasibinomial)
pander(Anova(m, test = "F"))

#'
#' \newpage
#' 
summary(m)




# /* 
# ---------------- Dinocampus : Comparing emergence rates between species -------------------
# */

#'
#' \newpage
#' 
#' 
#' ## Comparing emergence rate between species
#' 
#' ### Graphs 
#' 
#' The data for the other species than H. axyridis are quite scarce : 
#' 

#+ fig.width = 20/2.54, fig.height = 12/2.54
# dev.new(width = 20/2.54, height = 12/2.54)
tmp <- droplevels(d[!is.na(d$Emergence_rate),])
ggplot(tmp, aes(y = Emergence_rate, x = Continent)) + 
    geom_point(aes(size = Emergence_N), shape = 1) +
    facet_wrap(~Host,  nrow = 2) + 
    scale_size_continuous(name = "Sample size", breaks = c(35, 57, 125, 500, 18952))+
    ylab("Dinocampus coccinellae\nEmergence rate (%)") + xlab("") + 
    theme_bw() +
    theme(axis.text.x=element_text(angle=45, hjust=1), legend.position = "top")

#' 
#' We could compare the emergence rate of _H.axyridis_ and the parasitism rate 
#' of all other species confounded. There are no data for emergence rate in the native area
#' so we use only data from invaded areas.
#' The lines connect observations from the same study and the same year (ie data that are directly comparable). 
#'    
#'    
#'    

tmp <- droplevels(d[!is.na(d$Emergence_rate),])
tmp$Species <- as.character(tmp$Host)
tmp[tmp$Species != "Harmonia axyridis", "Species"] <- "Other sp."
tmp[tmp$Species == "Harmonia axyridis", "Species"] <- "H.axyridis"
tmp$Species <- factor(tmp$Species)
# crates an ID variable for each study in a given year
tmp$Study_ID <- factor(paste(tmp$Year, tmp$Reference))
tmp$Observation_ID <- factor(1:nrow(tmp))


# ggplot(tmp, aes(y = Parasitism_rate, x = Species)) + 
#     geom_point(aes(size = Parasitism_N), shape = 1) +
#     geom_line(aes(group = Study_ID), color = "gray50") +
#     facet_wrap(~Range) + 
#     scale_size_continuous(name = "Sample size", breaks = c(14, 100, 250, 450, 1652))+
#     ylab("Parasitism rate (%)") + xlab("") +
#     theme_bw()


tmp2 <- tmp[, c("Emergence_rate", "Species", "Range", "Study_ID"),]
tmp2 <- merge(tmp2[tmp2$Species == "H.axyridis",], tmp2[tmp2$Species != "H.axyridis",], 
              by = "Study_ID", all = TRUE)
colnames(tmp2)[4] <- "Range"

#+ fig.width = 9/2.54, fig.height = 6/2.54
# dev.new(width = 9/2.54, height = 6/2.54)
ggplot(tmp, aes(y = Emergence_rate, x = Species)) + 
    geom_point(aes(size = Emergence_N), shape = 1) +
    geom_segment(aes(group = Study_ID, 
                     xend = Species.x, yend = Emergence_rate.x, 
                     x = Species.y, y = Emergence_rate.y), 
                 color = "gray50", data = tmp2) +
    facet_wrap(~Range) + 
    scale_size_continuous(name = "Sample size", breaks = c(35, 57, 125, 500, 18952))+
    ylab("Dinocampus coccinellae\nEmergence rate (%)") + xlab("") +
    theme_bw()

#'
#' \newpage
#'
#' 
#' ### Binomial GLMM
#' 
#' ***Is the emergence rate different between H.axyridis and the other species ?***
#' 
#' We used only the data from the invaded regions because the data from the native range was not available.   
#' We used a binomial Generalized Linear Mixed Model (GLMM) with the emergence rate as 
#' response and the Species (_H. axyridis_ vs Other species) as fixed explanatory variable.
#' The study (data from one publication and one year) was used as random effect. 
#' An observation level ID was added as random effect to take into account any overdispersion. 
#' 
#' The results show that there the other species have a significantly higher emergence rate
#' (binomial GLMM coefficient = 1.85, se = 0.555, z = 3.334, p = 0.0009)
#' 
#' Note : The model do not converge without observation level 
#' random effects.
#' 
m <- glmer(Emergence_rate/100 ~ Species + (1 |Study_ID) + (1|Observation_ID), 
           weights = Emergence_N, family = binomial, 
           data = tmp[tmp$Range == "Invaded area",])

# overdisp(m)
summary(m)

#'
#' \newpage
#'
#' 
#' ### Paired t test by permutation
#' 
#' We tried a simpler approach with a paired t test using only the data for which 
#' there was both measures of parasitism for _H.axyridis_ and other species (and repeating 
#' the data for H.axyridis when there are several other species in the same study - this is not optimal).
#' As the parasitism rate could not be expected to follow a normal distribution we estimated the p value
#' with a permutation test (10000 permutations). The p value from the standard paired t test
#' is provided along with the permutation test p value
#' 



tmp3 <- tmp2[!is.na(tmp2$Emergence_rate.y) & tmp2$Range == "Invaded area", ]
tmp3 <- tmp3[c("Emergence_rate.y", "Emergence_rate.x")]

# Observed t statistic from a paired t test
res <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)
obs.t <- res$statistic

nperm = 10000 # number of permutations
perm.t <- vector(length = nperm)
set.seed(1234)
for (i in 1:(nperm-1)) {
    tmp3[] <- sample(as.matrix(tmp3)) # permute the data
    perm.t[i] <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)$statistic
}
perm.t[nperm] <- obs.t
perm.p <- 1 -(sum(abs(obs.t) >= abs(perm.t))/nperm)

res <- data.frame(t = round(res$statistic, 4), df = res$parameter, 
                  p.value = round(res$p.value, 4), "perm.p.value" = perm.p)

#' 
#' The paired difference of parasitism level between _H. axyridis_ and the other species 
#' in the invaded areas is significant  : t = 3.8404, df = 12, p = `r perm.p`
#'  
#

pander(res)


#' 
#' ### Conclusion
#' 
#' The data seem to consistently point toward a signifianctly lower level of emergence 
#' of _Dinocampus coccinellae_ when using _H.axyridis_ as host relative to other species in the invaded regions.
#' This is based on a variety of data collected from the literature from studies using different
#' protocols, with different objectives and with no systematic assessment of the native fauna. 
#' So these results should be confirmed by more standardised approaches.
#' 


# /* 
# ---------------- Dinocampus : Evolution of emergence across time -------------------
# */

#'
#' \newpage
#' 
#' 
#' ## Changes in emergence rate across time
#' 
#' The idea here was to test if there could be a time lag between the invasion and the adoption
#' of a new host by local parasitoïds (as observed in the parasitic fungus _Hesperomyces virescens_ 
#' sensu Haelewaters et al. 2017).
#' 
#' For the data collected during a range of years (e.g. 2004-2008), 
#' we use the mean of the range as "year".
#' 
#' The data are quite limited and don't seem to show any clear pattern
#' 

#+ fig.width = 18/2.54, fig.height = 7/2.54
# dev.new(width = 18/2.54, height = 7/2.54)
tmp <- droplevels(d[d$Host == "Harmonia axyridis" & !is.na(d$Emergence_rate),])
tmp$Year <- rowMeans(tmp[, c("Year_start", "Year")], na.rm = TRUE)
ggplot(tmp, aes(y = Emergence_rate, x = Year)) + 
    geom_point(aes(size = Emergence_N), shape = 1) +
    facet_wrap(~Continent, scales = "free", nrow = 1) +
    ylab("Dinocampus coccinellae\nEmergence rate (%)") + xlab("") +
    scale_size_continuous(name = "Sample size", breaks = c(35, 57, 125, 500, 18952))+
    theme_bw() +
    theme(legend.position = "top", axis.text.x=element_text(angle=45, hjust=1))







# /* 
# ---------------- Phalacrotophora  -------------------
# */



#'
#' \newpage
#' 

#' 
#' # _Phalacrotophora spp._ {#Phalaco}
#' 
#' 
#' Summary of the data :
#' 
#' For 15 data from the native range, we have the parasitism rate but not the sample size.
#' For the other data the minimum sample size is N = 98 and the median is N = 450. 
#' So we imputed the missing sample size with a value N = 50 which seems to be a conservative
#' estimate. This data is only used in the binomial GLM and GLMM as weight for each observation.
#' 
#' 

d <- read.csv("data/Phalacrotophora.csv")
d$Imputed_N <- is.na(d$Parasitism_N)
d[is.na(d$Parasitism_N), "Parasitism_N"] <- 50
summary(d)


# /* 
# ---------------- Phalacrotophora : Comparing parasitism rates between regions -------------------
# */

#'
#' \newpage
#' 
#' 
#' ## Comparing parasitism rates between regions
#' 
#' ### Graph 
#' 

#+ fig.width = 9/2.54, fig.height = 6/2.54
# dev.new(width = 9/2.54, height = 6/2.54)
tmp <- droplevels(d[d$Host == "Harmonia axyridis" & !is.na(d$Parasitism_rate),])
set.seed(123)
ggplot(tmp, aes(y = Parasitism_rate, x = Continent)) + 
    geom_point(aes(size = Parasitism_N), shape = 1, position = position_jitter(width = 0.1)) +
    facet_wrap(~ Host) +
    ylab("Phalacrotophora spp.\nparasitism rate (%)") + xlab("") +
    scale_size_continuous(name = "Sample size", breaks = c(50, 120, 500, 1000, 4508))+
    theme_bw() +
    theme(legend.position = "right")


#'
#' ### GLM
#'
#' ***Is the parasitism rate of H. axyridis by Phalacrotophora spp. different between regions (continents) ?***
#' 
#' We performed a Binomial GLM with a quasilikelihood approach to estimate the 
#' overdispersion coefficient (that is quite high here : ~ 11.5).   
#' There is a highly significant lower parastism rate in Eyrope relative to the native range 
#' (quasibinomial GLM, $F_{1,15}$ = 19.68, p = 0.0005).   
#' NB : we use a specific F test adapted to overdispersed GLMs instead of the more classical
#' Likelihood Ratio Test
#' 
m <- glm(Parasitism_rate/100 ~ Continent, weight = Parasitism_N, 
         data = tmp, family = quasibinomial)
pander(Anova(m, test = "F"))

#'
#' \newpage
#' 
summary(m)





# /* 
# ---------------- Phalacrotophora : Comparing parasitism rates between species -------------------
# */

#'
#' \newpage
#' 
#' 
#' ## Comparing parasitism rate between species
#' 
#' ### Graphs 
#' 
#' The data for the other species than _H.axyridis_ are quite scarce : 
#' 

#+ fig.width = 20/2.54, fig.height = 13/2.54
# dev.new(width = 20/2.54, height = 13/2.54)
tmp <- droplevels(d[!is.na(d$Parasitism_rate),])
ggplot(tmp, aes(y = Parasitism_rate, x = Continent)) + 
    geom_point(aes(size = Parasitism_N), shape = 1) +
    facet_wrap(~Host,  nrow = 2) + 
    scale_size_continuous(name = "Sample size", breaks = c(50, 120, 500, 1000, 4508))+
    ylab("Phalacrotophora spp.\nparasitism rate (%)") + xlab("") + 
    theme_bw() +
    theme(axis.text.x=element_text(angle=45, hjust=1), legend.position = "top")

#' 
#' We could compare the parasitism rate of _H.axyridis_ and the parasitism rate 
#' of all other species confounded. We keep the native range data separated from the invades areas.
#' The lines connect observations from the same study and the same year (ie data that are directly comparable). 
#' 
#' NB : In the Native range, the 2 "other species" with higher parasitism rate are 
#' _Anatis ocellata_
#'    

tmp <- droplevels(d[!is.na(d$Parasitism_rate),])
tmp$Species <- as.character(tmp$Host)
tmp[tmp$Species != "Harmonia axyridis", "Species"] <- "Other sp."
tmp[tmp$Species == "Harmonia axyridis", "Species"] <- "H.axyridis"
tmp$Species <- factor(tmp$Species)
# crates an ID variable for each study in a given year
tmp$Study_ID <- factor(paste(tmp$Year, tmp$Reference))
tmp$Observation_ID <- factor(1:nrow(tmp))


tmp2 <- tmp[, c("Parasitism_rate", "Species", "Range", "Study_ID"),]
tmp2 <- merge(tmp2[tmp2$Species == "H.axyridis",], tmp2[tmp2$Species != "H.axyridis",], 
              by = "Study_ID", all = TRUE)
colnames(tmp2)[4] <- "Range"

#+ fig.width = 12/2.54, fig.height = 6/2.54
# dev.new(width = 12/2.54, height = 6/2.54)
ggplot(tmp, aes(y = Parasitism_rate, x = Species)) + 
    geom_point(aes(size = Parasitism_N), shape = 1) +
    geom_segment(aes(group = Study_ID, 
                     xend = Species.x, yend = Parasitism_rate.x, 
                     x = Species.y, y = Parasitism_rate.y), 
                 color = "gray50", data = tmp2) +
    facet_wrap(~Range) + 
    scale_size_continuous(name = "Sample size", breaks = c(50, 120, 500, 1000, 4508))+
    ylab("Phalacrotophora spp.\nparasitism rate (%)") + xlab("") +
    theme_bw()

#'
#' \newpage
#'
#' 
#' ### Binomial GLMM
#' 
#' ***Is the parasitsim level different between H.axyridis and the other species ?***
#' 
#' In contrast with the _Dinocampus_ data, we used here both the data from the invaded regions 
#' and the native range (however with an arbitrary sample size = 50 for most native range data).   
#' We used a binomial Generalized Linear Mixed Model (GLMM) with the parasitism rate as 
#' response and the Species (_H. axyridis_ vs Other species), the region 
#' (native range or invaded area) and their interaction as fixed explanatory variables.
#' The study (data from one publication and one year) was used as random effect. 
#' An observation level ID was added as random effect to take into account any overdispersion. 
#' 
#' The Species x region interaction is highly significant as are the Species and region main effects.
#' In the invaded areas, the parasitism rate of _H. axyridis_ tends to be lower than the other
#' species while in the native range, the average parasitism rate is similar between H.axyridis
#' and the other species.
#' 

m <- glmer(Parasitism_rate/100 ~ Species * Range + (1 |Study_ID) + (1|Observation_ID), 
           weights = Parasitism_N, family = binomial, 
           data = tmp)

# overdisp(m)
summary(m)

#'
#' \newpage
#' 
#' % of parasitism estimated by the model for each region and group of species : 
m <- glmer(Parasitism_rate/100 ~ -1 + Species:Range + (1 |Study_ID) + (1|Observation_ID), 
           weights = Parasitism_N, family = binomial, 
           data = tmp)
pander(data.frame("Pct Parasitism" = round(100*plogis(fixef(m)), 2)))

#'
#' \newpage
#'
#' If we use the same approach but keeping only "Coccinella septempunctata" as "other species", 
#' The results are similar excepted that the parasitism level of H.axyridis tends to be higher 
#' than the parasitism level of C. septempunctata in the native range of H.axyridis 
#' (the differences tend to be null when you mix all other species).  
#' 
#' We can do this with C. septempunctata only because this is the only "other species" for 
#' which the quantity of data is sufficient. 

m <- glmer(Parasitism_rate/100 ~ Species * Range + (1 |Study_ID) + (1|Observation_ID), 
           weights = Parasitism_N, family = binomial, 
           data = tmp[tmp$Host %in% c("Harmonia axyridis", "Coccinella septempunctata"),])
summary(m)


m <- glmer(Parasitism_rate/100 ~ -1 + Species:Range + (1 |Study_ID) + (1|Observation_ID), 
           weights = Parasitism_N, family = binomial, 
           data = tmp[tmp$Host %in% c("Harmonia axyridis", "Coccinella septempunctata"),])
pander(data.frame("Pct Parasitism" = round(100*plogis(fixef(m)), 2)))


#'
#' \newpage
#'
#' 
#' ### Paired t test by permutation
#' 
#' We tried a simpler approach with a paired t test using only the data for which 
#' there was both measures of parasitism for H.axyridis and other species (and repeating 
#' the data for H.axyridis when there are several other species in the same study - this is not optimal).
#' As the parasitism rate could not be expected to follow a normal distribution we estimated the p value
#' with a permutation test (10000 permutations). We provide both the standard p value (p.value) 
#' and the permutation test p value (perm.p.value). The data from the native range and the invaded
#' areas are analysed separately.
#' 


tmp3 <- tmp2[!is.na(tmp2$Parasitism_rate.y) & tmp2$Range == "Invaded area", ]
tmp3 <- tmp3[c("Parasitism_rate.y", "Parasitism_rate.x")]

# Observed t statistic from a paired t test
res <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)
obs.t <- res$statistic

nperm = 10000 # number of permutations
perm.t <- vector(length = nperm)
set.seed(1234)
for (i in 1:(nperm-1)) {
    tmp3[] <- sample(as.matrix(tmp3)) # permute the data
    perm.t[i] <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)$statistic
}
perm.t[nperm] <- obs.t
perm.p <- 1 -(sum(abs(obs.t) >= abs(perm.t))/nperm)

res <- data.frame(t = round(res$statistic, 4), df = res$parameter, 
                  p.value = round(res$p.value, 4), "perm.p.value" = perm.p)

#' 
#' The difference of parasitism rate is highly significant in the invaded region :
#' 

pander(res)

#' 
#' In the native region, there is no significant difference ; 
#' 

tmp3 <- tmp2[!is.na(tmp2$Parasitism_rate.y) & tmp2$Range == "Native range", ]
tmp3 <- tmp3[c("Parasitism_rate.y", "Parasitism_rate.x")]

# Observed t statistic from a paired t test
res <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)
obs.t <- res$statistic

nperm = 10000 # number of permutations
perm.t <- vector(length = nperm)
set.seed(1234)
for (i in 1:(nperm-1)) {
    tmp3[] <- sample(as.matrix(tmp3)) # permute the data
    perm.t[i] <- t.test(x = tmp3[,1], tmp3[,2], paired = TRUE)$statistic
}
perm.t[nperm] <- obs.t
perm.p <- 1 -(sum(abs(obs.t) >= abs(perm.t))/nperm)

res <- data.frame(t = round(res$statistic, 4), df = res$parameter, 
                  p.value = round(res$p.value, 4), "perm.p.value" = perm.p)

pander(res)


#' 
#' ### Conclusion
#' 
#' The data seem to consistently point toward a signifianctly lower level of parasitism 
#' of H. axyridis by Phalacrotophora spp. in the invaded areas while there is no systematic 
#' difference in the native range.  
#' The Binomial model uses arbirary sample size for most of the native range data, however we choose
#' a conservative value of N=50. These sample sizes are not used by the paired student tests.  
#' This is based on a variety of data collected from the literature from studies using different
#' protocols, with different objectives and with no systematic assessment of the native fauna. 
#' So these results should be confirmed by more standardised approaches.
#' 




# /* 
# ---------------- Phalacrotophora : Evolution of parasitism across time -------------------
# */

#'
#' \newpage
#' 
#' 
#' ## Changes in parasitism across time
#' 
#' The idea here was to test if there could be a time lag between the invasion and the adoption
#' of a new host by local parasitoïds (as observed in the parasitic fungus _Hesperomyces virescens_ 
#' sensu Haelewaters et al. 2017).
#' 
#' For the data collected during a range of years, we use the mean on the range as "year".
#' The period range and the parasitism level are very different between Asia and Europe 
#' with no overlap : the scales are completely different).
#' 
#' Note that the parasitism rate is not expressed in % here for technical reasons 
#' (the GLM curve needs true rates and not %)
#' 


#+ fig.width = 12/2.54, fig.height = 7/2.54
# dev.new(width = 12/2.54, height = 7/2.54)
tmp <- droplevels(d[d$Host == "Harmonia axyridis" & !is.na(d$Parasitism_rate),])
tmp$Year <- rowMeans(tmp[, c("Year_start", "Year")], na.rm = TRUE)
tmp[tmp$Country == "England", "Country"] <- "UK"
ggplot(tmp, aes(y = Parasitism_rate/100, x = Year)) + 
    geom_point(aes(size = Parasitism_N), shape = 1) +
    stat_smooth(method = "glm", se = FALSE, formula = y ~ x,
                method.args=list(family="quasibinomial"))+
    facet_wrap(~Continent, scales = "free", nrow = 1) +
    ylab("Phalacrotophora spp.\nParasitism rate") + xlab("") +
    scale_size_continuous(name = "Sample size", breaks = c(50, 100, 300, 1000, 4508))+
    theme_bw() +
    theme(legend.position = "top")

#' We test if these trends are significant with a binomial GLM (estimated with quasilikelihood)
#' with the Continent (Asia vs Europe), the year and their interaction as explanatory variables.
#' Ideally we should take into account that there are repeated measures on the same country 
#' but this is not possible here because the data are too scarce.  
#' 
#' As the aim is not to test if there is a difference of slope between the two regions 
#' we used a non standard parametrisation here. In the coefficient table, the two last lines
#' are testing if the slope of each region is significantly different from 0 (instead of testing
#' if they are different from each other).
#' 
#' In Asia, the slope is negative (-0.02311) but estimated with a high imprecision the slope is not
#' significantly different from 0 (p = 0.4985).   
#' In Europe, the slope is positive (0.29984) and significant but close to the 0.05 alpha level (p = 0.0381).
#' 
#' 
#'  

m <- glm(Parasitism_rate/100 ~ -1 + Continent + Continent:Year, weights = Parasitism_N, 
         data = tmp, family = quasibinomial)
summary(m)


#' 
#' UK is the only European country with several year of data 
#' (Ware et al 2010 + Comont et al 2014). 
#' Here are the results with UK only : 
#' 

#+ fig.width = 10/2.54, fig.height = 6/2.54
# dev.new(width = 10/2.54, height = 6/2.54)
tmp <- tmp[tmp$Country == "UK",]
ggplot(tmp, aes(y = Parasitism_rate/100, x = Year)) + 
    geom_point(aes(size = Parasitism_N), shape = 1) +
    stat_smooth(method = "glm", se = FALSE, formula = y ~ x,
                method.args=list(family="quasibinomial"))+
    facet_wrap(~Country, scales = "free", nrow = 1) +
    ylab("Phalacrotophora spp.\nParasitism rate") + xlab("") +
    scale_size_continuous(name = "Sample size", breaks = c(278, 500, 2000, 3868))+
    theme_bw() +
    theme(legend.position = "right")

#' This seems pretty nice but the slope is not significantly different from 0 (p = 0.161): 

m <- glm(Parasitism_rate/100 ~ Year, weights = Parasitism_N, 
         data = tmp, family = quasibinomial)
summary(m)


#' **Conclusion** : there seem to be a weak trend toward an increased parasitism rate in 
#' Europe but this is very weak and clearly would need more longitudinal and comparable data...
#' 
#' 
#'
#' \newpage
#'
#'
#' # References and Session information
#' 
#' 
#' Haelewaters D, Zhao SY, Clusella-Trullas S, Cottrell TE, De Kesel A, Fiedler L, Herz A, 
#' Hesketh H, Hui C, Kleespies RG, Losey JE, Minnaar IA, Murray KM, Nedvěd O, Pfliegler WP, 
#' Raak-van den Berg CL, Riddick EW, Shapiro-Ilan DI, Smyth RR, Steenberg T, van Wielink PS, 
#' Viglášová S, Zhao Z, Ceryngier P and Roy HE (2017). Parasites of Harmonia axyridis: 
#' current research and perspectives. BioControl, 62(3), pp. 355-371.
#'  doi: 10.1007/s10526-016-9766-8 (URL: https://doi.org/10.1007/s10526-016-9766-8)
#'
#' **Citation of R and packages used :**  
#' 

#+ results = 'asis', echo = FALSE
cat("**R**   \n")
print(citation(), style = "text")
cat("\n   ")

pkgs <- sort(names(sessionInfo()$otherPkgs))
for(i in 1:length(pkgs)) {
    cat(paste0("**", pkgs[i], "**   \n"))
    print(citation(pkgs[i]), style = "text")
    cat("\n   ")
}

#'
#' \newpage
#'
#' **Session information**
#' 
sessionInfo()

